@@ -13,7 +13,7 @@ try:
 except ModuleNotFoundError:
     from .aggregation import aggregate
     from .merging import fast_agglomerate as agglomerate 
-    warnings.warn("This CLASSIX installation is not using Cython.")
+    # warnings.warn("This CLASSIX installation is not using Cython.")
     
 from .clustering import CLASSIX
 from .clustering import load_data
